/*
 * [PrepArkansas.java]
 *
 * Summary: One shot program to process tax data for Arkansas. Generates code for AmericanTax.java table.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2010-12-14 initial version
 */
package com.mindprod.americantax;

import java.io.IOException;
/*
individual lookup: http://www.arkansas.gov/dfa/excise_tax_v2/st_zip.html
download http://www.dfa.arkansas.gov/offices/exciseTax/salesanduse/Documents/cityCountyTaxTable.pdf arkansas.pdf
has two lists one of cities and  one of counties. Cities are labelled with counties.
arkansascounties.csv
#county       rate (exlude state tax)
Arkansas,     1.000
Ashley,       1.500
Baxter,       1.000
#county       city                rate
Pulaski,      Alexander,          2.000
Crawford,     Alma,               2.000
Arkansas,     Almyra,             1.000
Boone,        Alpena,             1.000
follow instructions in arkansas.btm to create these two files.
Run prepArkansas
Insert arkansasdistricts.csv into districttax.csv
make sure statetax.csv and rat e in constructor are up to date.
Run prepare
Build.
 */

/**
 * One shot program to process tax data for Arkansas. Generates code for AmericanTax.java table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.1 2010-12-10 update to produce CSV file without state tax included.
 * @since 2007-06-08
 */
public final class PrepArkansas extends PrepStateBase
    {
    /**
     * Constructor
     */
    private PrepArkansas()
        {
        super( "AR",
                "arkansas",
                6.0, /* since 2004 */
                true /* counties */,
                true /* cities */,
                false /* city and county files include state rate */,
                false /* convert to book case */,
                /* guess country rates */
                400 );
        }

    // default count and city processors are fine.
    @SuppressWarnings( { "InfiniteLoopStatement" } )
    public static void main( String[] args ) throws IOException
        {
        new PrepArkansas().prepare();
        }
    }
