/*
 * [PrepFlorida.java]
 *
 * Summary: One shot program to process tax data for Florida. Generates data for AmericanTax.java table.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2010-12-11 initial version, like Georgia.
 */
package com.mindprod.americantax;

import java.io.IOException;

/**
 * One shot program to process tax data for Florida. Generates data for AmericanTax.java table.
 * <p/>
 * Generates code for AmericanTax.java table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.1 2010-12-10 update to produce CSV file without state tax included.
 * @since 2010-12-10
 */
public final class PrepFlorida extends PrepStateBase
    {
    /**
     * Constructor
     */
    private PrepFlorida()
        {
        super( "FL",
                "florida",
                6.0 /* state sales tax 2013-04-03 */,
                true /* counties has floridaacounties.csv */,
                false /* no cities. No floridacities.csv */,
                false /* files not included in  state rate */,
                false /* convert to book case */,
                100 /* estimated counties */ );
        }

    /*
     * Florida sales taxes home: http://dor.myflorida.com/dor/forms/index.html
     * has sales tax and discretionary surcharge (county tax) and use tax. Has county taxes but no city taxes.
     * download http://dor.myflorida.com/dor/forms/2013/dr15dss.pdf  floridaraw.pdf  <-== has county rates.
     * <p/>
     * Copy paste the PDF file then tidy it to this format. Watch expiry dates.
     * # county       tax
     * Alachua,        0
     * Baker,          1
     * Bay,           .5
     * Bradford,       1
     * <p/>
     * and save as E:\com\mindprod\americantax\floridacounties.csv, is no floridacities.csv
     */
    // default counties
    @SuppressWarnings( { "InfiniteLoopStatement" } )
    public static void main( String[] args ) throws IOException
        {
        new PrepFlorida().prepare();
        }
    }
