/*
 * [PrepIowa.java]
 *
 * Summary: One shot program to process tax data for Iowa. Generates code for AmericanTax.java table.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2010-12-10 produce CSV file without state tax included.
 */
package com.mindprod.americantax;

import com.mindprod.common18.ST;
import com.mindprod.csv.CSVReader;

import java.io.IOException;

/**
 * One shot program to process tax data for Iowa. Generates code for AmericanTax.java table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2010-12-10 produce CSV file without state tax included.
 * @since 2010-12-10
 */
public final class PrepIowa extends PrepStateBase
    {
    /*
     * Generates code for AmericanTax.java table.
     * home: http://www.iowa.gov/tax/educate/localoption_rates_sunsets.html
     * http://www.iowa.gov/tax/educate/localoption.html
     *
     * 40- page by city
     * download http://www.iowa.gov/tax/business/lostcit-6Percent.pdf iowa.pdf
     * OCR, save to CSV, Strip columns not needed.
     * LOST means local tax. either 0 or 1%.
     * # county, city, local tax (state tax excluded)
     * "ADAIR ","Adair",1
     * "ADAIR ","Bridgewater",1
     * "ADAIR ","Casey",1
     * "ADAIR ","Fontanelle",1
     * and save as E:\com\mindprod\americantax\iowacities.csv
     *
     * Iowa cities have typical population of 500.  That is why there are so many.
     */

    /**
     * Constructor
     */
    private PrepIowa()
        {
        super( "IA",
                "iowa",
                6.0 /* state tax rate */,
                false /* no iowacounties.csv */,
                true /* iowacities.csv exists  */,
                false /* files do not include state rate */,
                true /* convert to book case */,
                1500 /* estimated cities */ );
        }

    /**
     * Default method to read and prepare one county record.
     * You must read, and add SalesTaxItem to salesTaxItems, and skipToNewLine
     *
     * @param c open CSV reader.
     *
     * @throws IOException if cannot read file
     */
    void prepareCity( final CSVReader c ) throws IOException
        {
        final String county = ST.toBookTitleCase( c.get() );
        String city = c.get();
        final double percent = c.getDouble();
        c.skipToNextLine();
        if ( city.endsWith( "Unincorporated" ) )
            {
            city = "";  // turn it into a county record.
            }
        salesTaxItems.add( new SalesTaxItem( county, city, percent ) );
        }

    public static void main( String[] args ) throws IOException
        {
        new PrepIowa().prepare();
        }
    }
