/*
 * [PrepLouisiana.java]
 *
 * Summary: One shot program to process tax data for Louisiana. Generates data for AmericanTax.java table.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2010-12-11 initial, like New York
 */
package com.mindprod.americantax;

import com.mindprod.common18.ST;
import com.mindprod.csv.CSVReader;

import java.io.IOException;

import static java.lang.System.*;

/**
 * One shot program to process tax data for Louisiana. Generates data for AmericanTax.java table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2010-12-11 initial, like New York
 * @since 2010-12-11
 */
public final class PrepLouisiana extends PrepStateBase
    {
    /*
* for Louisiana see http://www.laota.com/pta.htm, separate body handles local sales tax.
* home: http://revenue.louisiana.gov/sections/business/sales.aspx#sales
* online rate lookup http://www.laota.com/index.php?option=com_content&view=article&id=168&Itemid=146
* http://www.laota.com/index.php?option=com_content&view=article&id=168&Itemid=146 <-- rate lookup, Can "print" all.
* 3.97 percent Louisiana state sales tax, and .03 percent Louisiana Tourism Promotion District sales tax total 4%.
* Louisiana privatizes tax collection to each parish.  Each parish has its own webpage, not even in standard format.
* The website is missing 50% of the tags in the strangest HTML I have ever seen. It is bizarre!
*
* We copy the PDF file to a CSV file. We use without to strip out lines not needed. After much manual
* work we end up with a file like this louisianaboth.csv
* #either
# parish                                 parish tax rate  (does not include state)
#
or
#city                                    city tax rate  (includes county, but not state)
#
Acadia Parish,                            4.250
Crowley,                                  5.500,
Church Point,                             4.250,
Iota,                                     5.250,
The cities following a Parish belong to that parish. */

    /**
     * used to propagate Parish to following cities
     */
    private String county;

    private double countyPercent;

    /**
     * Constructor
     */
    private PrepLouisiana()
        {
        super( "LA",
                "louisiana",
                4.0,
                false /* counties */,
                true /* cities */,
                false /* files include state rate */,
                false /* no convert to book case */,
                /* guess country rates */
                600 );
        }

    /**
     * Default method to read and prepare one county record.
     * You must read, and add SalesTaxItem to salesTaxItems, and skipToNewLine
     *
     * @param c open CSV reader.
     *
     * @throws IOException if cannot read file
     */
    void prepareCity( final CSVReader c ) throws IOException
        {
        final String first = c.get();
        if ( first == null )
            {
            /* ignore blank lines */
            /* by reading the null, we have already skipped to the next line */
            return;
            }
        // this might be a Parish or a city.  Decide which
        if ( first.endsWith( "Parish" ) && !first.contains( " in " ) )
            {
            // this was a parish/country record
            county = ST.chopTrailingString( first, " Parish" );
            countyPercent = c.getDouble();//   state tax already stripped
            if ( countyPercent < 0 )
                {
                err.println( "county: " + county + " has negative tax" );
                }
            salesTaxItems.add( new SalesTaxItem( county, "", countyPercent ) );
            }
        else
            {
            // it was a city record
            final String city = first;
            final double cityPercent = c.getDouble();// state tax already stripped.
            if ( cityPercent < 0 )
                {
                err.println( "county: " + county + " city:" + city + " has negative tax" );
                }
            if ( cityPercent != countyPercent )
                {
                // leave out if has rate as county. Get country from prenvious read.
                salesTaxItems.add( new SalesTaxItem( county, city, cityPercent ) );
                }
            }
        c.skipToNextLine();
        }

    @SuppressWarnings( { "InfiniteLoopStatement" } )
    public static void main( String[] args ) throws IOException
        {
        new PrepLouisiana().prepare();
        }
    }
