/*
 * [PrepNewYork.java]
 *
 * Summary: One shot program to process tax data for New York. Generates code for AmericanTax.java table.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2010-12-11 initial, like Tennessee
 */
package com.mindprod.americantax;

import java.io.IOException;

/**
 * One shot program to process tax data for New York. Generates code for AmericanTax.java table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2010-12-11 initial, like Tennessee
 * @since 2010-12-11
 */
public final class PrepNewYork extends PrepStateBase
    {
    /*
    * For New York district
    * home: http://www.tax.state.ny.us/nyshome/stidx.htm
    * download http://www.tax.state.ny.us/pdf/publications/sales/pub718.pdf newyorkraw.pdf
    * combined county/city PDF
    * New York tate and Local Sales Tax Rates by Community also
    * http://ny.rand.org/stats/govtfin/salestax.html 2010-02-10
    * as 20column HTML Table rounds .375 to .38 , out of date.
    * http://www.photobooksonline.com/books/salestax.html, single column, out of date
    * prune out (city)
    When you have massaged enough it will look like this:  newyorkcities.csv
    #county                  city                tax rate including state
    Albany,                  ,                    8
    Allegany,                ,                    8
    Broome,                  ,                    8
    Cattaraugus,             ,                    8
    Cattaraugus,             Olean (city),        8
    */

    /**
     * Constructor
     */
    private PrepNewYork()
        {
        super( "NY", "newyork", 4.0,
                false /* counties */,
                true /* cities */,
                true /* files include state rate */,
                false /* convert to book case */,
                100 /* estimated items */ );
        }

    public static void main( String[] args ) throws IOException
        {
        new PrepNewYork().prepare();
        }
    }
