/*
 * [PrepNorthCarolina.java]
 *
 * Summary: One shot program to process tax data for North Carolina. Generates code for AmericanTax.java table.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2008-05-22
 *  1.1 2010-12-10 update to produce CSV file without state tax included.
 */
package com.mindprod.americantax;

import java.io.IOException;

/**
 * One shot program to process tax data for North Carolina. Generates code for AmericanTax.java table.
 * <p/>
 * Generates code for AmericanTax.java table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.1 2010-12-10 update to produce CSV file without state tax included.
 * @since 2008-05-22
 */
public final class PrepNorthCarolina extends PrepStateBase
    {
    /*
     * home: http://www.dor.state.nc.us/taxes/sales/taxrates.html
     * download http://www.dor.state.nc.us/taxes/sales/salesrates_1-11.html northcarolinaraw.html
     * <p/>
     * Copy paste the html file then tidy it to this format, converting  % to \n and \t to ,
     * Plus other minor tidies. Can use table reshape to extract columns.
     * Just counties. No city overrides.
     * Alamance,6.75
     * Alexander,7
     * Alleghany,6.75
     * Anson,6.75
     * Ashe,6.75
     * Avery,6.75
     * Beaufort,6.75
     * <p/>
     * and save as E:\com\mindprod\americantax\northcarolinacounties.csv
     */

    /**
     * Constructor
     */
    private PrepNorthCarolina()
        {
        super( "NC",
                "northcarolina",
                5.750,
                true /* counties */,
                false /* cities */,
                true /* files include state rate */,
                false /* convert to book case */,
                2000 );
        }

    public static void main( String[] args ) throws IOException
        {
        new PrepNorthCarolina().prepare();
        }
    }
