/*
 * [PrepWisconsin.java]
 *
 * Summary: One shot program to process tax data for Wisconsin. Generates code for AmericanTax.java table.
 *
 * Copyright: (c) 2008-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2008-06-01
 *  1.1 2010-12-10 update to produce CSV file without state tax included.
 */
package com.mindprod.americantax;

import java.io.IOException;

/**
 * One shot program to process tax data for Wisconsin. Generates code for AmericanTax.java table.
 * <p/>
 * Generates code for AmericanTax.java table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.1 2010-12-10 update to produce CSV file without state tax included.
 * @since 2008-06-01
 */
public final class PrepWisconsin extends PrepStateBase
    {
    /*
     * http://www.revenue.wi.gov/faqs/pcs/taxrates.html#txrate11
     * E:\com\mindprod\americantax\wisconsintax.csv
     * county, total tax rate (including  5% state sales tax and, .5% county tax)
     * Adams,        5.50
     * Ashland,      5.50
     * Barron,       5.50
     */

    /**
     * Constructor
     */
    private PrepWisconsin()
        {
        super( "WI",
                "wisconsin",
                5.0,
                true /* counties */,
                false /* cities */,
                true /* files include state rate */,
                false /* convert to book case */,
                100 );
        }

    public static void main( String[] args ) throws IOException
        {
        new PrepWisconsin().prepare();
        }
    }
