/*
 * [PrepWyoming.java]
 *
 * Summary: One shot program to process tax data for Wyoming. Generates code for AmericanTax.java table.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2010-12-11 initial, like Louisiana
 */
package com.mindprod.americantax;

import java.io.IOException;

/**
 * One shot program to process tax data for Wyoming. Generates code for AmericanTax.java table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2010-12-11 initial, like Louisiana
 * @since 2010-12-11
 */
public class PrepWyoming extends PrepStateBase
    {
    /*
     * for Wyoming the home is:
     * http://revenue.state.wy.us/PortalVBVS/DesktopDefault.aspx?tabindex=3&tabid=10
     * You can download a Excel spreadsheet giving city, county and total tax.
     * Throw away columns not needed, and export as CSV
     * massage wyomingcounties.csv till it looks like this: Prune out non-counties.
     * #county     tax including state tax
     * Albany,      6.00
     * Big Horn,    5.00
     * Campbell,    5.00
     * Carbon,      6.00
     * Massage wyomingcities.csv till it looks like this. Use CSVReshape, CSVSort, VS dedup.:
     * # CountyName, city         tax including state tax.
     * Albany,      Albany,          6.00
     * Albany,      Bosler,          6.00
     * Albany,      Buford,          6.00
     * All cities have same rate as county, so might as well not be cities.
     */

    /**
     * Constructor
     */
    private PrepWyoming()
        {
        super( "WY",
                "wyoming",
                4.0,
                true /* counties */,
                true /* cities */,
                true /* files include state rate */,
                false /* no convert to book case */,
                /* guess country rates */
                600 );
        }

    @SuppressWarnings( { "InfiniteLoopStatement" } )
    public static void main( String[] args ) throws IOException
        {
        new PrepWyoming().prepare();
        }
    }
